.. _lock_module:

:mod:`kazoo.recipe.lock`
----------------------------

.. automodule:: kazoo.recipe.lock

Public API
++++++++++

    .. autoclass:: Lock
        :members:

        .. automethod:: __init__

    .. autoclass:: ReadLock
        :members:
        :inherited-members:

        .. automethod:: __init__

    .. autoclass:: WriteLock
        :members:
        :inherited-members:

        .. automethod:: __init__

    .. autoclass:: Semaphore
        :members:

        .. automethod:: __init__
